using MagicOnion;

namespace DysonNetwork.Shared.Services;

public interface IAccountUsernameService : IService<IAccountUsernameService>
{
    /// <summary>
    /// Generates a unique username based on the provided base name
    /// </summary>
    /// <param name="baseName">The preferred username</param>
    /// <returns>A unique username</returns>
    Task<string> GenerateUniqueUsernameAsync(string baseName);
    
    /// <summary>
    /// Checks if a username already exists
    /// </summary>
    Task<bool> IsUsernameExistsAsync(string username);
    
    /// <summary>
    /// Sanitizes a username to remove invalid characters
    /// </summary>
    string SanitizeUsername(string username);
}
